@@ -24,15 +24,16 @@
 #define TESTPIECETABLECHANGETEST_H
 
 // Qt
-#include <QObject>
+#include <QtCore/QObject>
 
-namespace KPieceTable {
+namespace KPieceTable
+{
 
 class TestPieceTableChangeTest : public QObject
 {
-    Q_OBJECT
+  Q_OBJECT
 
-private Q_SLOTS: // test functions
+  private Q_SLOTS: // test functions
     void testSimpleConstructor();
     void testMerge();
 };
